@@ -3,7 +3,7 @@ package Dist::Zilla::PluginBundle::Author::SHARYANTO;
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 use Dist::Zilla::PluginBundle::Filter;
 
@@ -30,7 +30,7 @@ sub configure {
 
         # to help make sure that I have the latest plugins
         ['Run::BeforeBuild' => {run => 'exec-if-not-env OFFLINE norepeat -p daily -- cpanm -n --reinstall Dist::Zilla::PluginBundle::Author::SHARYANTO Pod::Weaver::PluginBundle::Author::SHARYANTO'}],
-        ['Run::Release' => {run => 'archive-perl-release %s' . ($ENV{INSTALL} // 1 ? " && cpanm %s" : "")}],
+        ['Run::Release' => {run => ['archive-perl-release %s', ('cpanm %s') x !!($ENV{INSTALL} // 1) ]}],
     );
 }
 
@@ -51,7 +51,7 @@ Dist::Zilla::PluginBundle::Author::SHARYANTO - Dist::Zilla like SHARYANTO when y
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
